@@ -1023,8 +1023,8 @@ class TestPostConfig(BaseTestCase):
         mock_swift_client.return_value = mock_instance_swift
 
         mock_heat = mock.Mock()
-        aux_stack = {}
-        aux_stack['stack_name'] = "mystack"
+        aux_stack = mock.Mock()
+        aux_stack.stack_name = "mystack"
         mock_heat.stacks.list.return_value = [aux_stack]
         mock_make_client.return_value = mock_heat
 
@@ -1064,8 +1064,8 @@ class TestPostConfig(BaseTestCase):
         mock_swift_client.return_value = mock_instance_swift
 
         mock_heat = mock.Mock()
-        aux_stack = {}
-        aux_stack['stack_name'] = "mystackooo"
+        aux_stack = mock.Mock()
+        aux_stack.stack_name = "mystackooo"
         mock_heat.stacks.list.return_value = [aux_stack]
         mock_make_client.return_value = mock_heat
 
@@ -1090,7 +1090,7 @@ class TestPostConfig(BaseTestCase):
         mock_mistral.executions.get.return_value = mock.Mock(state="FAIL")
         mock_mistral.executions.get_output.return_value = "ERROR!"
         mock_mistral.executions.get.id = "1234"
-        mock_mistral.action_executions.list.return_value = []
+        mock_mistral.action_executions.find.return_value = []
 
         mock_auth_values.return_value = ('aturing', '3nigma', 'hut8',
                                          'http://bletchley:5000/')
@@ -1102,8 +1102,8 @@ class TestPostConfig(BaseTestCase):
         mock_swift_client.return_value = mock_instance_swift
 
         mock_heat = mock.Mock()
-        aux_stack = {}
-        aux_stack['stack_name'] = "mystack"
+        aux_stack = mock.Mock()
+        aux_stack.stack_name = "mystack"
         mock_heat.stacks.list.return_value = [aux_stack]
         mock_make_client.return_value = mock_heat
 
@@ -1129,7 +1129,7 @@ class TestPostConfig(BaseTestCase):
         mock_mistral_client.return_value = mock_mistral
         mock_mistral.environments.list.return_value = []
         mock_mistral.executions.get.id = "1234"
-        mock_mistral.action_executions.list.return_value = []
+        mock_mistral.action_executions.find.return_value = []
         mock_instance_swift = mock.Mock()
 
         mock_auth_values.return_value = ('aturing', '3nigma', 'hut8',
@@ -1142,8 +1142,8 @@ class TestPostConfig(BaseTestCase):
         mock_swift_client.return_value = mock_instance_swift
 
         mock_heat = mock.Mock()
-        aux_stack = {}
-        aux_stack['stack_name'] = "mystack"
+        aux_stack = mock.Mock()
+        aux_stack.stack_name = "mystack"
         mock_heat.stacks.list.return_value = [aux_stack]
         mock_make_client.return_value = mock_heat
 
@@ -1241,7 +1241,7 @@ class TestPostConfig(BaseTestCase):
     def test_create_default_plan_failed(self, mock_strptime):
         mock_mistral = mock.Mock()
         mock_mistral.executions.get.return_value = mock.Mock(state="ERROR")
-        mock_mistral.action_executions.list.return_value = []
+        mock_mistral.action_executions.find.return_value = []
         mock_strptime.return_value = time.mktime(time.localtime())
         self.assertRaises(
             RuntimeError,
